@@ -7,11 +7,12 @@
 """
 from trytond.pool import Pool
 
-from production import Production
+from production import Production, Configuration
 
 
 def register():
     Pool.register(
         Production,
+        Configuration,
         module='production_disassembly', type_='model'
     )
